@@ -51,12 +51,13 @@ image_shape = (28, 28)
 diamond_collector = run(images=X[0:100],
                         image_shape=image_shape,
                         labels=y[0:100],
-                        get_image_description=True,
+                        get_image_description=False,
                         is_augment_data=True,
+                        detect_faces=False,
                         image_augmentation_info=ImagesAugmentationInfo(aug_prop=0.2),
-                        is_train_model=False, image_models=image_models,
-                        is_post_model_analysis=False,
-                        plot=False)
+                        is_train_model=True, image_models=image_models,
+                        is_post_model_analysis=True,
+                        plot=True)
 
 # labels handling
 # image convert to np nd array
